require "faraday"
require "json"

require "slacklet/store/version"

module Slacklet
  class Store
    class Error < StandardError; end
    class RecordNotFound < Error ; end

		def initialize(base_url, token)
      @token    = token
      @base_url = base_url
    end
    
    def get(key)
      request(:get, "/records/#{key}")["value"]
    rescue RecordNotFound
      return nil
    end

    def set(key, value)
      request(:put, "/records/#{key}", value: value)
    end

    def delete(key)
      request(:delete, "/records/#{key}")
    end 

    private

    def request(method, path, params = {})
      resp = Faraday.send(method, "#{@base_url}#{path}", params) do |req|
        req.headers["x-store-token"] = @token
      end

      data = JSON.load(resp.body)

      if resp.success?
        return data
      end

      case resp.status
      when 404
        raise RecordNotFound.new(data["message"])
      else
        raise Error.new(data["message"])
      end
    end
  end
end
